@@ -3,7 +3,6 @@ package DBIx::Class::Schema::Loader::DBObject;
 use strict;
 use warnings;
 use base 'Class::Accessor::Grouped';
-use mro 'c3';
 use Carp::Clan qw/^DBIx::Class/;
 use Scalar::Util 'weaken';
 use namespace::clean;
@@ -34,9 +33,7 @@ __PACKAGE__->mk_group_accessors(simple => qw/
 /);
 
 use overload
-    '""' => sub { $_[0]->name },
-    '@{}' => sub { $_[0]->name_parts },
-    fallback => 1;
+    '""' => sub { $_[0]->name };
 
 =head2 new
 
@@ -154,20 +151,6 @@ sub dbic_name {
     return $self->name;
 }
 
-=head2 name_parts
-
-Returns an arrayref of the values returned by the methods specified in
-the L<moniker_parts|DBIx::Class::Scheam::Loader::Base/moniker_parts> of
-the L</loader> object. The object arrayrefifies to this value.
-
-=cut
-
-sub name_parts {
-    my ($self) = shift;
-    return [ map { $self->$_ } @{$self->loader->moniker_parts} ];
-}
-
-
 =head1 SEE ALSO
 
 L<DBIx::Class::Schema::Loader::Table>, L<DBIx::Class::Schema::Loader>,
